import os
from flask import Flask, jsonify, request, redirect, url_for, abort, render_template, send_from_directory
import markdown
from datetime import datetime
from urllib.parse import unquote

app = Flask(__name__)

POSTS_FOLDER = './posts.md'

@app.route('/')
def home():
    return render_template('index.html')
@app.route('/about')
def about():
    return render_template('index.html')
@app.route('/services')
def services():
    return render_template('index.html')
@app.route('/contact')
def contact():
    return render_template('index.html')
@app.route('/arc')
def arc():
    return render_template('index.html')

# Route for listing all available posts - /posts
@app.route('/posts')
def get_posts():
    # List of tuples containing (filename without .md, last modified timestamp)
    posts = []
    
    # Loop through all markdown files in the posts folder
    for f in os.listdir(POSTS_FOLDER):
        if f.endswith('.md'):
            # Get the full file path
            file_path = os.path.join(POSTS_FOLDER, f)
            
            # Get the file modification time
            modified_time = os.path.getmtime(file_path)
            
            # Append the file name without the .md extension and the modified time
            posts.append((f[:-3].replace('-', ' '), modified_time))
    
    # Sort the list by modification time (newest first)
    posts.sort(key=lambda x: x[1], reverse=False)
    
    # Pass only the file names (first element of each tuple) to the template
    return render_template('posts.html', posts=[r[0] for r in posts])


# Route for serving an individual blog post - /post/<post_name>
@app.route('/post/<post_name>')
def serve_post(post_name):
    # Use hyphens in the file system and lowercase for file naming
    post_file = os.path.join(POSTS_FOLDER, unquote(post_name).lower() + '.md')

    # Check if the post file exists
    if os.path.exists(post_file):
        # Read and convert the markdown content to HTML
        with open(post_file, 'r', encoding='utf-8') as file:
            content = file.read()
            html_content = markdown.markdown(content)

        # Get the file modification time and format it as a readable date
        modified_time = os.path.getmtime(post_file)
        post_date = datetime.fromtimestamp(modified_time).strftime('%B %d, %Y')

        # Render the post template with the converted content and post date
        return render_template('post.html', post_content=html_content, post_name=post_name.replace('-', ' ').title(), post_date=post_date)
    else:
        return abort(404)

@app.context_processor
def inject_year():
    return dict(year=datetime.now().year)

if __name__ == "__main__":
    app.run(debug=True)
